# Seriousity

Serious tool for serious people. I'm serious.

## Getting started

For serious people there should be serious software. That's why we are here. By **`we`** I mean **`I`**. Because serious people are always alone.

## Prerequisites

Before you start installation you should:

- Install Python 3.x
- Install pip

But the main prerequisite - **BE SERIOUS**. It is important.

## Installation

> **CATION**: you need to be completely serious while installation. DON'T SMILE🧐 Serious people don't smile. You smile, you die. That's the law.

When get serious, type this in your terminal:

```bash
pip install seriousity
```

It should install seriousity on your machine. It was seriously tested so if you got an error then **you was not serious enough while installation**. That's the case. Errors are not for serious people.

## Usage

If you seriously weighed the pros and cons then you should become incredibly s-s (i.e. serious, abbreviations are for s-s people). So you ready to start your serious business. The command is below. Good luck.

```bash
seriousity start seriously
```

## License

Serious people don't use licenses. They are licenses themselves. See [LICENSE.md](LICENSE.md) if you don't trust me.
